#!/bin/sh
HOSTNAME="localhost"
PORT="3306"
USERNAME="root"
DBNAME="oat_db"
REQS_TAB="attest_request"
AUDIT_LOG_TAB="audit_log"
SUMMARY_TAB="summary_request"

#remove aulit_log before 1 day
`mysql -h$HOSTNAME -P$PORT -u$USERNAME $DBNAME -e "delete from $AUDIT_LOG_TAB where timestamp <= NOW() - INTERVAL 1 DAY"`
if [ $? -eq 0 ]; then \
       echo "Delete Audit logs Successful!"
else
       echo "Delete Audit logs Failed!"
       exit 1
fi

#remove the requests before 1 day
reqs=`mysql -h$HOSTNAME -P$PORT -u$USERNAME $DBNAME -e "select host_name,result from $REQS_TAB where validate_time <= now() - INTERVAL 1 DAY order by host_name" | tail -n +2 | cut -d ' ' -f1,2| sort | uniq -c | awk '{OFS=",";print $1,$2,$3;}'`
reqsSize=`echo "$reqs" | awk '{size+=$1}END{print size}'`
mysql -h$HOSTNAME -P$PORT -u$USERNAME $DBNAME -e "delete from $REQS_TAB order by validate_time limit $reqsSize"
#mysql -h$HOSTNAME -P$PORT -u$USERNAME $DBNAME -e "delete from $REQS_TAB where validate_time <= NOW() - INTERVAL 1 DAY"
if [ $? -eq 0 ]; then \
       echo "Deleted Requests:$reqsSize"
else
       echo "Delete Requests Failed!"
       exit 1
fi

#backup the deleted requests into summary table
len=`echo "$reqs" | wc -l`
echo "$reqs" | while read req
do
	loop=`expr $loop + 1`;
	num=`echo | awk -v "req=$req" 'BEGIN{split(req,reqArr,",");print reqArr[1]}'`
	host_name=`echo | awk -v "req=$req" 'BEGIN{split(req,reqArr,",");print reqArr[2]}'`
	result=`echo | awk -v "req=$req" 'BEGIN{split(req,reqArr,",");print reqArr[3]}'`
	if [[ "$previous_host_name" = "" || "$host_name" != "$previous_host_name" ]]; then 
		attest_untrusted=0 attest_trusted=0 attest_unknown=0 attest_timeout=0
	else
		unset summary[loop-1]
	fi
	case $result in
		0) attest_untrusted="$num" ;;
		1) attest_trusted="$num" ;;
		2) attest_unknown="$num" ;;
		3) attest_timeout="$num" ;;
	esac;
	summary[$loop]=\"$host_name\",$attest_untrusted,$attest_trusted,$attest_unknown,$attest_timeout
	previous_host_name=$host_name
	if [ $loop -eq $len ]; then
	{
		for s in ${summary[*]}; do
			mysql -h$HOSTNAME -P$PORT -u$USERNAME $DBNAME -e "insert into $SUMMARY_TAB(host_name,attest_untrusted,attest_trusted,attest_unknown,attest_timeout,end_time) values($s,now())"
		done; 
	}
	fi
done
if [ $? -eq 0 ]; then \
       echo "Requests Cleaning Successful!"
       exit 0
else
       echo "Requests Cleaning Failed!"
       exit 1
fi
